@@ -1,13 +1,17 @@
 package main
 
 import (
+	"context"
 	"fmt"
 	"net/http"
 	"net/http/httptest"
 	"regexp"
 	"testing"
 
+	"gitlab.com/gitlab-org/labkit/correlation"
+
 	"github.com/dgrijalva/jwt-go"
+	"github.com/stretchr/testify/require"
 
 	"gitlab.com/gitlab-org/gitlab-workhorse/internal/api"
 	"gitlab.com/gitlab-org/gitlab-workhorse/internal/helper"
@@ -23,22 +27,21 @@ func okHandler(w http.ResponseWriter, _ *http.Request, _ *api.Response) {
 
 func runPreAuthorizeHandler(t *testing.T, ts *httptest.Server, suffix string, url *regexp.Regexp, apiResponse interface{}, returnCode, expectedCode int) *httptest.ResponseRecorder {
 	if ts == nil {
-		ts = testAuthServer(url, nil, returnCode, apiResponse)
+		ts = testAuthServer(t, url, nil, returnCode, apiResponse)
 		defer ts.Close()
 	}
 
 	// Create http request
-	httpRequest, err := http.NewRequest("GET", "/address", nil)
-	if err != nil {
-		t.Fatal(err)
-	}
+	ctx := correlation.ContextWithCorrelation(context.Background(), "12345678")
+	httpRequest, err := http.NewRequestWithContext(ctx, "GET", "/address", nil)
+	require.NoError(t, err)
 	parsedURL := helper.URLMustParse(ts.URL)
 	testhelper.ConfigureSecret()
 	a := api.NewAPI(parsedURL, "123", roundtripper.NewTestBackendRoundTripper(parsedURL))
 
 	response := httptest.NewRecorder()
 	a.PreAuthorizeHandler(okHandler, suffix).ServeHTTP(response, httpRequest)
-	testhelper.AssertResponseCode(t, response, expectedCode)
+	require.Equal(t, expectedCode, response.Code)
 	return response
 }
 
@@ -68,9 +71,8 @@ func TestPreAuthorizeJsonFailure(t *testing.T) {
 
 func TestPreAuthorizeContentTypeFailure(t *testing.T) {
 	ts := httptest.NewServer(http.HandlerFunc(func(w http.ResponseWriter, r *http.Request) {
-		if _, err := w.Write([]byte(`{"hello":"world"}`)); err != nil {
-			t.Fatalf("write auth response: %v", err)
-		}
+		_, err := w.Write([]byte(`{"hello":"world"}`))
+		require.NoError(t, err, "write auth response")
 	}))
 	defer ts.Close()
 
@@ -108,27 +110,16 @@ func TestPreAuthorizeJWT(t *testing.T) {
 
 			return secretBytes, nil
 		})
-		if err != nil {
-			t.Fatalf("decode token: %v", err)
-		}
+		require.NoError(t, err, "decode token")
 
 		claims, ok := token.Claims.(jwt.MapClaims)
-		if !ok {
-			t.Fatal("claims cast failed")
-		}
-
-		if !token.Valid {
-			t.Fatal("JWT token invalid")
-		}
-
-		if claims["iss"] != "gitlab-workhorse" {
-			t.Fatalf("execpted issuer gitlab-workhorse, got %q", claims["iss"])
-		}
+		require.True(t, ok, "claims cast")
+		require.True(t, token.Valid, "JWT token valid")
+		require.Equal(t, "gitlab-workhorse", claims["iss"], "JWT token issuer")
 
 		w.Header().Set("Content-Type", api.ResponseContentType)
-		if _, err := w.Write([]byte(`{"hello":"world"}`)); err != nil {
-			t.Fatalf("write auth response: %v", err)
-		}
+		_, err = w.Write([]byte(`{"hello":"world"}`))
+		require.NoError(t, err, "write auth response")
 	}))
 	defer ts.Close()
 
