@@ -4,16 +4,18 @@ package main
 
 import (
 	"archive/tar"
+	"bufio"
 	"bytes"
 	"context"
 	"fmt"
 	"os"
 	"os/exec"
 	"path"
+	"regexp"
 	"strconv"
+	"strings"
 	"testing"
 
-	"github.com/stretchr/testify/assert"
 	"github.com/stretchr/testify/require"
 	"gitlab.com/gitlab-org/gitaly/proto/go/gitalypb"
 
@@ -88,7 +90,7 @@ func TestAllowedClone(t *testing.T) {
 	require.NoError(t, ensureGitalyRepository(t, apiResponse))
 
 	// Prepare test server and backend
-	ts := testAuthServer(nil, nil, 200, apiResponse)
+	ts := testAuthServer(t, nil, nil, 200, apiResponse)
 	defer ts.Close()
 	ws := startWorkhorseServer(ts.URL)
 	defer ws.Close()
@@ -112,7 +114,7 @@ func TestAllowedShallowClone(t *testing.T) {
 	require.NoError(t, ensureGitalyRepository(t, apiResponse))
 
 	// Prepare test server and backend
-	ts := testAuthServer(nil, nil, 200, apiResponse)
+	ts := testAuthServer(t, nil, nil, 200, apiResponse)
 	defer ts.Close()
 	ws := startWorkhorseServer(ts.URL)
 	defer ws.Close()
@@ -136,7 +138,7 @@ func TestAllowedPush(t *testing.T) {
 	require.NoError(t, ensureGitalyRepository(t, apiResponse))
 
 	// Prepare the test server and backend
-	ts := testAuthServer(nil, nil, 200, apiResponse)
+	ts := testAuthServer(t, nil, nil, 200, apiResponse)
 	defer ts.Close()
 	ws := startWorkhorseServer(ts.URL)
 	defer ws.Close()
@@ -175,10 +177,10 @@ func TestAllowedGetGitBlob(t *testing.T) {
 	require.NoError(t, err)
 	shortBody := string(body[:len(expectedBody)])
 
-	assert.Equal(t, 200, resp.StatusCode, "GET %q: status code", resp.Request.URL)
-	assert.Equal(t, expectedBody, shortBody, "GET %q: response body", resp.Request.URL)
-	testhelper.AssertResponseHeader(t, resp, "Content-Length", strconv.Itoa(bodyLen))
-	assertNginxResponseBuffering(t, "no", resp, "GET %q: nginx response buffering", resp.Request.URL)
+	require.Equal(t, 200, resp.StatusCode, "GET %q: status code", resp.Request.URL)
+	require.Equal(t, expectedBody, shortBody, "GET %q: response body", resp.Request.URL)
+	testhelper.RequireResponseHeader(t, resp, "Content-Length", strconv.Itoa(bodyLen))
+	requireNginxResponseBuffering(t, "no", resp, "GET %q: nginx response buffering", resp.Request.URL)
 }
 
 func TestAllowedGetGitArchive(t *testing.T) {
@@ -202,8 +204,8 @@ func TestAllowedGetGitArchive(t *testing.T) {
 
 	resp, body, err := doSendDataRequest("/archive.tar", "git-archive", jsonParams)
 	require.NoError(t, err)
-	assert.Equal(t, 200, resp.StatusCode, "GET %q: status code", resp.Request.URL)
-	assertNginxResponseBuffering(t, "no", resp, "GET %q: nginx response buffering", resp.Request.URL)
+	require.Equal(t, 200, resp.StatusCode, "GET %q: status code", resp.Request.URL)
+	requireNginxResponseBuffering(t, "no", resp, "GET %q: nginx response buffering", resp.Request.URL)
 
 	// Ensure the tar file is readable
 	foundEntry := false
@@ -220,7 +222,7 @@ func TestAllowedGetGitArchive(t *testing.T) {
 		}
 	}
 
-	assert.True(t, foundEntry, "Couldn't find %v directory entry", archivePrefix)
+	require.True(t, foundEntry, "Couldn't find %v directory entry", archivePrefix)
 }
 
 func TestAllowedGetGitArchiveOldPayload(t *testing.T) {
@@ -247,8 +249,8 @@ func TestAllowedGetGitArchiveOldPayload(t *testing.T) {
 
 	resp, body, err := doSendDataRequest("/archive.tar", "git-archive", jsonParams)
 	require.NoError(t, err)
-	assert.Equal(t, 200, resp.StatusCode, "GET %q: status code", resp.Request.URL)
-	assertNginxResponseBuffering(t, "no", resp, "GET %q: nginx response buffering", resp.Request.URL)
+	require.Equal(t, 200, resp.StatusCode, "GET %q: status code", resp.Request.URL)
+	requireNginxResponseBuffering(t, "no", resp, "GET %q: nginx response buffering", resp.Request.URL)
 
 	// Ensure the tar file is readable
 	foundEntry := false
@@ -265,7 +267,7 @@ func TestAllowedGetGitArchiveOldPayload(t *testing.T) {
 		}
 	}
 
-	assert.True(t, foundEntry, "Couldn't find %v directory entry", archivePrefix)
+	require.True(t, foundEntry, "Couldn't find %v directory entry", archivePrefix)
 }
 
 func TestAllowedGetGitDiff(t *testing.T) {
@@ -290,9 +292,9 @@ func TestAllowedGetGitDiff(t *testing.T) {
 	require.NoError(t, err)
 	shortBody := string(body[:len(expectedBody)])
 
-	assert.Equal(t, 200, resp.StatusCode, "GET %q: status code", resp.Request.URL)
-	assert.Equal(t, expectedBody, shortBody, "GET %q: response body", resp.Request.URL)
-	assertNginxResponseBuffering(t, "no", resp, "GET %q: nginx response buffering", resp.Request.URL)
+	require.Equal(t, 200, resp.StatusCode, "GET %q: status code", resp.Request.URL)
+	require.Equal(t, expectedBody, shortBody, "GET %q: response body", resp.Request.URL)
+	requireNginxResponseBuffering(t, "no", resp, "GET %q: nginx response buffering", resp.Request.URL)
 }
 
 func TestAllowedGetGitFormatPatch(t *testing.T) {
@@ -314,10 +316,10 @@ func TestAllowedGetGitFormatPatch(t *testing.T) {
 	resp, body, err := doSendDataRequest("/something", "git-format-patch", jsonParams)
 	require.NoError(t, err)
 
-	assert.Equal(t, 200, resp.StatusCode, "GET %q: status code", resp.Request.URL)
-	assertNginxResponseBuffering(t, "no", resp, "GET %q: nginx response buffering", resp.Request.URL)
+	require.Equal(t, 200, resp.StatusCode, "GET %q: status code", resp.Request.URL)
+	requireNginxResponseBuffering(t, "no", resp, "GET %q: nginx response buffering", resp.Request.URL)
 
-	testhelper.AssertPatchSeries(
+	requirePatchSeries(
 		t,
 		body,
 		"372ab6950519549b14d220271ee2322caa44d4eb",
@@ -327,3 +329,29 @@ func TestAllowedGetGitFormatPatch(t *testing.T) {
 		rightCommit,
 	)
 }
+
+var extractPatchSeriesMatcher = regexp.MustCompile(`^From (\w+)`)
+
+// RequirePatchSeries takes a `git format-patch` blob, extracts the From xxxxx
+// lines and compares the SHAs to expected list.
+func requirePatchSeries(t *testing.T, blob []byte, expected ...string) {
+	t.Helper()
+	var actual []string
+	footer := make([]string, 3)
+
+	scanner := bufio.NewScanner(bytes.NewReader(blob))
+
+	for scanner.Scan() {
+		line := scanner.Text()
+		if matches := extractPatchSeriesMatcher.FindStringSubmatch(line); len(matches) == 2 {
+			actual = append(actual, matches[1])
+		}
+		footer = []string{footer[1], footer[2], line}
+	}
+
+	require.Equal(t, strings.Join(expected, "\n"), strings.Join(actual, "\n"), "patch series")
+
+	// Check the last returned patch is complete
+	// Don't assert on the final line, it is a git version
+	require.Equal(t, "-- ", footer[0], "end of patch marker")
+}
