@@ -17,9 +17,8 @@ import (
 	"testing"
 	"time"
 
-	"github.com/golang/protobuf/jsonpb"
-	"github.com/golang/protobuf/proto"
-	"github.com/stretchr/testify/assert"
+	"github.com/golang/protobuf/jsonpb" //lint:ignore SA1019 https://gitlab.com/gitlab-org/gitlab-workhorse/-/issues/274
+	"github.com/golang/protobuf/proto"  //lint:ignore SA1019 https://gitlab.com/gitlab-org/gitlab-workhorse/-/issues/274
 	"github.com/stretchr/testify/require"
 	"google.golang.org/grpc"
 	"google.golang.org/grpc/codes"
@@ -44,7 +43,7 @@ func TestFailedCloneNoGitaly(t *testing.T) {
 	}
 
 	// Prepare test server and backend
-	ts := testAuthServer(nil, nil, 200, authBody)
+	ts := testAuthServer(t, nil, nil, 200, authBody)
 	defer ts.Close()
 	ws := startWorkhorseServer(ts.URL)
 	defer ws.Close()
@@ -53,12 +52,12 @@ func TestFailedCloneNoGitaly(t *testing.T) {
 	cloneCmd := exec.Command("git", "clone", fmt.Sprintf("%s/%s", ws.URL, testRepo), checkoutDir)
 	out, err := cloneCmd.CombinedOutput()
 	t.Log(string(out))
-	assert.Error(t, err, "git clone should have failed")
+	require.Error(t, err, "git clone should have failed")
 }
 
 func TestGetInfoRefsProxiedToGitalySuccessfully(t *testing.T) {
 	gitalyServer, socketPath := startGitalyServer(t, codes.OK)
-	defer gitalyServer.Stop()
+	defer gitalyServer.GracefulStop()
 
 	gitalyAddress := "unix:" + socketPath
 
@@ -96,7 +95,7 @@ func TestGetInfoRefsProxiedToGitalySuccessfully(t *testing.T) {
 		t.Run(fmt.Sprintf("ShowAllRefs=%v,gitRpc=%v", tc.showAllRefs, tc.gitRpc), func(t *testing.T) {
 			apiResponse.ShowAllRefs = tc.showAllRefs
 
-			ts := testAuthServer(nil, nil, 200, apiResponse)
+			ts := testAuthServer(t, nil, nil, 200, apiResponse)
 			defer ts.Close()
 
 			ws := startWorkhorseServer(ts.URL)
@@ -143,12 +142,12 @@ func TestGetInfoRefsProxiedToGitalySuccessfully(t *testing.T) {
 func TestGetInfoRefsProxiedToGitalyInterruptedStream(t *testing.T) {
 	apiResponse := gitOkBody(t)
 	gitalyServer, socketPath := startGitalyServer(t, codes.OK)
-	defer gitalyServer.Stop()
+	defer gitalyServer.GracefulStop()
 
 	gitalyAddress := "unix:" + socketPath
 	apiResponse.GitalyServer.Address = gitalyAddress
 
-	ts := testAuthServer(nil, nil, 200, apiResponse)
+	ts := testAuthServer(t, nil, nil, 200, apiResponse)
 	defer ts.Close()
 
 	ws := startWorkhorseServer(ts.URL)
@@ -167,6 +166,11 @@ func TestGetInfoRefsProxiedToGitalyInterruptedStream(t *testing.T) {
 		close(done)
 	}()
 
+	waitDone(t, done)
+}
+
+func waitDone(t *testing.T, done chan struct{}) {
+	t.Helper()
 	select {
 	case <-done:
 		return
@@ -179,11 +183,11 @@ func TestPostReceivePackProxiedToGitalySuccessfully(t *testing.T) {
 	apiResponse := gitOkBody(t)
 
 	gitalyServer, socketPath := startGitalyServer(t, codes.OK)
-	defer gitalyServer.Stop()
+	defer gitalyServer.GracefulStop()
 
 	apiResponse.GitalyServer.Address = "unix:" + socketPath
 	apiResponse.GitConfigOptions = []string{"git-config-hello=world"}
-	ts := testAuthServer(nil, nil, 200, apiResponse)
+	ts := testAuthServer(t, nil, nil, 200, apiResponse)
 	defer ts.Close()
 
 	ws := startWorkhorseServer(ts.URL)
@@ -209,26 +213,26 @@ func TestPostReceivePackProxiedToGitalySuccessfully(t *testing.T) {
 	gitalyRequest := &gitalypb.PostReceivePackRequest{}
 	require.NoError(t, jsonpb.UnmarshalString(split[0], gitalyRequest))
 
-	assert.Equal(t, apiResponse.Repository.StorageName, gitalyRequest.Repository.StorageName)
-	assert.Equal(t, apiResponse.Repository.RelativePath, gitalyRequest.Repository.RelativePath)
-	assert.Equal(t, apiResponse.GL_ID, gitalyRequest.GlId)
-	assert.Equal(t, apiResponse.GL_USERNAME, gitalyRequest.GlUsername)
-	assert.Equal(t, apiResponse.GitConfigOptions, gitalyRequest.GitConfigOptions)
-	assert.Equal(t, gitProtocol, gitalyRequest.GitProtocol)
+	require.Equal(t, apiResponse.Repository.StorageName, gitalyRequest.Repository.StorageName)
+	require.Equal(t, apiResponse.Repository.RelativePath, gitalyRequest.Repository.RelativePath)
+	require.Equal(t, apiResponse.GL_ID, gitalyRequest.GlId)
+	require.Equal(t, apiResponse.GL_USERNAME, gitalyRequest.GlUsername)
+	require.Equal(t, apiResponse.GitConfigOptions, gitalyRequest.GitConfigOptions)
+	require.Equal(t, gitProtocol, gitalyRequest.GitProtocol)
 
-	assert.Equal(t, 200, resp.StatusCode, "POST %q", resource)
+	require.Equal(t, 200, resp.StatusCode, "POST %q", resource)
 	require.Equal(t, string(testhelper.GitalyReceivePackResponseMock), split[1])
-	testhelper.AssertResponseHeader(t, resp, "Content-Type", "application/x-git-receive-pack-result")
+	testhelper.RequireResponseHeader(t, resp, "Content-Type", "application/x-git-receive-pack-result")
 }
 
 func TestPostReceivePackProxiedToGitalyInterrupted(t *testing.T) {
 	apiResponse := gitOkBody(t)
 
 	gitalyServer, socketPath := startGitalyServer(t, codes.OK)
-	defer gitalyServer.Stop()
+	defer gitalyServer.GracefulStop()
 
 	apiResponse.GitalyServer.Address = "unix:" + socketPath
-	ts := testAuthServer(nil, nil, 200, apiResponse)
+	ts := testAuthServer(t, nil, nil, 200, apiResponse)
 	defer ts.Close()
 
 	ws := startWorkhorseServer(ts.URL)
@@ -241,7 +245,7 @@ func TestPostReceivePackProxiedToGitalyInterrupted(t *testing.T) {
 		bytes.NewReader(testhelper.GitalyReceivePackResponseMock),
 	)
 	require.NoError(t, err)
-	assert.Equal(t, 200, resp.StatusCode, "POST %q", resource)
+	require.Equal(t, 200, resp.StatusCode, "POST %q", resource)
 
 	// This causes the server stream to be interrupted instead of consumed entirely.
 	resp.Body.Close()
@@ -252,12 +256,7 @@ func TestPostReceivePackProxiedToGitalyInterrupted(t *testing.T) {
 		close(done)
 	}()
 
-	select {
-	case <-done:
-		return
-	case <-time.After(10 * time.Second):
-		t.Fatal("time out waiting for gitaly handler to return")
-	}
+	waitDone(t, done)
 }
 
 // ReaderFunc is an adapter to turn a conforming function into an io.Reader.
@@ -280,10 +279,10 @@ func TestPostUploadPackProxiedToGitalySuccessfully(t *testing.T) {
 			apiResponse.ShowAllRefs = tc.showAllRefs
 
 			gitalyServer, socketPath := startGitalyServer(t, tc.code)
-			defer gitalyServer.Stop()
+			defer gitalyServer.GracefulStop()
 
 			apiResponse.GitalyServer.Address = "unix:" + socketPath
-			ts := testAuthServer(nil, nil, 200, apiResponse)
+			ts := testAuthServer(t, nil, nil, 200, apiResponse)
 			defer ts.Close()
 
 			ws := startWorkhorseServer(ts.URL)
@@ -314,14 +313,12 @@ func TestPostUploadPackProxiedToGitalySuccessfully(t *testing.T) {
 			)
 			defer resp.Body.Close()
 			require.Equal(t, 200, resp.StatusCode, "POST %q", resource)
-			testhelper.AssertResponseHeader(t, resp, "Content-Type", "application/x-git-upload-pack-result")
+			testhelper.RequireResponseHeader(t, resp, "Content-Type", "application/x-git-upload-pack-result")
 
 			m.Lock()
 			requestFinished := requestReadFinished
 			m.Unlock()
-			if !requestFinished {
-				t.Fatalf("response written before request was fully read")
-			}
+			require.True(t, requestFinished, "response written before request was fully read")
 
 			body := string(testhelper.ReadAll(t, resp.Body))
 			bodySplit := strings.SplitN(body, "\000", 2)
@@ -349,10 +346,10 @@ func TestPostUploadPackProxiedToGitalyInterrupted(t *testing.T) {
 	apiResponse := gitOkBody(t)
 
 	gitalyServer, socketPath := startGitalyServer(t, codes.OK)
-	defer gitalyServer.Stop()
+	defer gitalyServer.GracefulStop()
 
 	apiResponse.GitalyServer.Address = "unix:" + socketPath
-	ts := testAuthServer(nil, nil, 200, apiResponse)
+	ts := testAuthServer(t, nil, nil, 200, apiResponse)
 	defer ts.Close()
 
 	ws := startWorkhorseServer(ts.URL)
@@ -365,7 +362,7 @@ func TestPostUploadPackProxiedToGitalyInterrupted(t *testing.T) {
 		bytes.NewReader(testhelper.GitalyUploadPackResponseMock),
 	)
 	require.NoError(t, err)
-	assert.Equal(t, 200, resp.StatusCode, "POST %q", resource)
+	require.Equal(t, 200, resp.StatusCode, "POST %q", resource)
 
 	// This causes the server stream to be interrupted instead of consumed entirely.
 	resp.Body.Close()
@@ -376,17 +373,12 @@ func TestPostUploadPackProxiedToGitalyInterrupted(t *testing.T) {
 		close(done)
 	}()
 
-	select {
-	case <-done:
-		return
-	case <-time.After(10 * time.Second):
-		t.Fatal("time out waiting for gitaly handler to return")
-	}
+	waitDone(t, done)
 }
 
 func TestGetDiffProxiedToGitalySuccessfully(t *testing.T) {
 	gitalyServer, socketPath := startGitalyServer(t, codes.OK)
-	defer gitalyServer.Stop()
+	defer gitalyServer.GracefulStop()
 
 	gitalyAddress := "unix:" + socketPath
 	repoStorage := "default"
@@ -400,13 +392,13 @@ func TestGetDiffProxiedToGitalySuccessfully(t *testing.T) {
 	resp, body, err := doSendDataRequest("/something", "git-diff", jsonParams)
 	require.NoError(t, err)
 
-	assert.Equal(t, 200, resp.StatusCode, "GET %q: status code", resp.Request.URL)
-	assert.Equal(t, expectedBody, string(body), "GET %q: response body", resp.Request.URL)
+	require.Equal(t, 200, resp.StatusCode, "GET %q: status code", resp.Request.URL)
+	require.Equal(t, expectedBody, string(body), "GET %q: response body", resp.Request.URL)
 }
 
 func TestGetPatchProxiedToGitalySuccessfully(t *testing.T) {
 	gitalyServer, socketPath := startGitalyServer(t, codes.OK)
-	defer gitalyServer.Stop()
+	defer gitalyServer.GracefulStop()
 
 	gitalyAddress := "unix:" + socketPath
 	repoStorage := "default"
@@ -420,13 +412,13 @@ func TestGetPatchProxiedToGitalySuccessfully(t *testing.T) {
 	resp, body, err := doSendDataRequest("/something", "git-format-patch", jsonParams)
 	require.NoError(t, err)
 
-	assert.Equal(t, 200, resp.StatusCode, "GET %q: status code", resp.Request.URL)
-	assert.Equal(t, expectedBody, string(body), "GET %q: response body", resp.Request.URL)
+	require.Equal(t, 200, resp.StatusCode, "GET %q: status code", resp.Request.URL)
+	require.Equal(t, expectedBody, string(body), "GET %q: response body", resp.Request.URL)
 }
 
 func TestGetBlobProxiedToGitalyInterruptedStream(t *testing.T) {
 	gitalyServer, socketPath := startGitalyServer(t, codes.OK)
-	defer gitalyServer.Stop()
+	defer gitalyServer.GracefulStop()
 
 	gitalyAddress := "unix:" + socketPath
 	repoStorage := "default"
@@ -447,17 +439,12 @@ func TestGetBlobProxiedToGitalyInterruptedStream(t *testing.T) {
 		close(done)
 	}()
 
-	select {
-	case <-done:
-		return
-	case <-time.After(10 * time.Second):
-		t.Fatal("time out waiting for gitaly handler to return")
-	}
+	waitDone(t, done)
 }
 
 func TestGetArchiveProxiedToGitalySuccessfully(t *testing.T) {
 	gitalyServer, socketPath := startGitalyServer(t, codes.OK)
-	defer gitalyServer.Stop()
+	defer gitalyServer.GracefulStop()
 
 	gitalyAddress := "unix:" + socketPath
 	repoStorage := "default"
@@ -481,9 +468,9 @@ func TestGetArchiveProxiedToGitalySuccessfully(t *testing.T) {
 		resp, body, err := doSendDataRequest("/archive.tar.gz", "git-archive", jsonParams)
 		require.NoError(t, err)
 
-		assert.Equal(t, 200, resp.StatusCode, "GET %q: status code", resp.Request.URL)
-		assert.Equal(t, expectedBody, string(body), "GET %q: response body", resp.Request.URL)
-		assert.Equal(t, archiveLength, len(body), "GET %q: body size", resp.Request.URL)
+		require.Equal(t, 200, resp.StatusCode, "GET %q: status code", resp.Request.URL)
+		require.Equal(t, expectedBody, string(body), "GET %q: response body", resp.Request.URL)
+		require.Equal(t, archiveLength, len(body), "GET %q: body size", resp.Request.URL)
 
 		if tc.cacheDisabled {
 			_, err := os.Stat(tc.archivePath)
@@ -498,7 +485,7 @@ func TestGetArchiveProxiedToGitalySuccessfully(t *testing.T) {
 
 func TestGetArchiveProxiedToGitalyInterruptedStream(t *testing.T) {
 	gitalyServer, socketPath := startGitalyServer(t, codes.OK)
-	defer gitalyServer.Stop()
+	defer gitalyServer.GracefulStop()
 
 	gitalyAddress := "unix:" + socketPath
 	repoStorage := "default"
@@ -521,17 +508,12 @@ func TestGetArchiveProxiedToGitalyInterruptedStream(t *testing.T) {
 		close(done)
 	}()
 
-	select {
-	case <-done:
-		return
-	case <-time.After(10 * time.Second):
-		t.Fatal("time out waiting for gitaly handler to return")
-	}
+	waitDone(t, done)
 }
 
 func TestGetDiffProxiedToGitalyInterruptedStream(t *testing.T) {
 	gitalyServer, socketPath := startGitalyServer(t, codes.OK)
-	defer gitalyServer.Stop()
+	defer gitalyServer.GracefulStop()
 
 	gitalyAddress := "unix:" + socketPath
 	repoStorage := "default"
@@ -553,17 +535,12 @@ func TestGetDiffProxiedToGitalyInterruptedStream(t *testing.T) {
 		close(done)
 	}()
 
-	select {
-	case <-done:
-		return
-	case <-time.After(10 * time.Second):
-		t.Fatal("time out waiting for gitaly handler to return")
-	}
+	waitDone(t, done)
 }
 
 func TestGetPatchProxiedToGitalyInterruptedStream(t *testing.T) {
 	gitalyServer, socketPath := startGitalyServer(t, codes.OK)
-	defer gitalyServer.Stop()
+	defer gitalyServer.GracefulStop()
 
 	gitalyAddress := "unix:" + socketPath
 	repoStorage := "default"
@@ -585,17 +562,12 @@ func TestGetPatchProxiedToGitalyInterruptedStream(t *testing.T) {
 		close(done)
 	}()
 
-	select {
-	case <-done:
-		return
-	case <-time.After(10 * time.Second):
-		t.Fatal("time out waiting for gitaly handler to return")
-	}
+	waitDone(t, done)
 }
 
 func TestGetSnapshotProxiedToGitalySuccessfully(t *testing.T) {
 	gitalyServer, socketPath := startGitalyServer(t, codes.OK)
-	defer gitalyServer.Stop()
+	defer gitalyServer.GracefulStop()
 
 	gitalyAddress := "unix:" + socketPath
 	expectedBody := testhelper.GitalyGetSnapshotResponseMock
@@ -605,19 +577,19 @@ func TestGetSnapshotProxiedToGitalySuccessfully(t *testing.T) {
 	resp, body, err := doSendDataRequest("/api/v4/projects/:id/snapshot", "git-snapshot", params)
 	require.NoError(t, err)
 
-	assert.Equal(t, http.StatusOK, resp.StatusCode, "GET %q: status code", resp.Request.URL)
-	assert.Equal(t, expectedBody, string(body), "GET %q: body", resp.Request.URL)
-	assert.Equal(t, archiveLength, len(body), "GET %q: body size", resp.Request.URL)
+	require.Equal(t, http.StatusOK, resp.StatusCode, "GET %q: status code", resp.Request.URL)
+	require.Equal(t, expectedBody, string(body), "GET %q: body", resp.Request.URL)
+	require.Equal(t, archiveLength, len(body), "GET %q: body size", resp.Request.URL)
 
-	testhelper.AssertResponseHeader(t, resp, "Content-Disposition", `attachment; filename="snapshot.tar"`)
-	testhelper.AssertResponseHeader(t, resp, "Content-Type", "application/x-tar")
-	testhelper.AssertResponseHeader(t, resp, "Content-Transfer-Encoding", "binary")
-	testhelper.AssertResponseHeader(t, resp, "Cache-Control", "private")
+	testhelper.RequireResponseHeader(t, resp, "Content-Disposition", `attachment; filename="snapshot.tar"`)
+	testhelper.RequireResponseHeader(t, resp, "Content-Type", "application/x-tar")
+	testhelper.RequireResponseHeader(t, resp, "Content-Transfer-Encoding", "binary")
+	testhelper.RequireResponseHeader(t, resp, "Cache-Control", "private")
 }
 
 func TestGetSnapshotProxiedToGitalyInterruptedStream(t *testing.T) {
 	gitalyServer, socketPath := startGitalyServer(t, codes.OK)
-	defer gitalyServer.Stop()
+	defer gitalyServer.GracefulStop()
 
 	gitalyAddress := "unix:" + socketPath
 
@@ -634,12 +606,7 @@ func TestGetSnapshotProxiedToGitalyInterruptedStream(t *testing.T) {
 		close(done)
 	}()
 
-	select {
-	case <-done:
-		return
-	case <-time.After(10 * time.Second):
-		t.Fatal("time out waiting for gitaly handler to return")
-	}
+	waitDone(t, done)
 }
 
 func buildGetSnapshotParams(gitalyAddress string, repo *gitalypb.Repository) string {
