@@ -76,8 +76,9 @@ type MultipartUploadParams struct {
 }
 
 type ObjectStorageParams struct {
-	Provider string
-	S3Config config.S3Config
+	Provider      string
+	S3Config      config.S3Config
+	GoCloudConfig config.GoCloudConfig
 }
 
 type RemoteObject struct {
@@ -147,6 +148,8 @@ type Response struct {
 	ProcessLsif bool
 	// Detects whether LSIF artifact will be parsed with references
 	ProcessLsifReferences bool
+	// The maximum accepted size in bytes of the upload
+	MaximumSize int64
 }
 
 // singleJoiningSlash is taken from reverseproxy.go:NewSingleHostReverseProxy
@@ -185,6 +188,8 @@ func (api *API) newRequest(r *http.Request, suffix string) (*http.Request, error
 		Header: helper.HeaderClone(r.Header),
 	}
 
+	authReq = authReq.WithContext(r.Context())
+
 	// Clean some headers when issuing a new request without body
 	authReq.Header.Del("Content-Type")
 	authReq.Header.Del("Content-Encoding")
