@@ -14,7 +14,6 @@ import (
 	"testing"
 	"time"
 
-	"github.com/stretchr/testify/assert"
 	"github.com/stretchr/testify/require"
 
 	"gitlab.com/gitlab-org/gitlab-workhorse/internal/api"
@@ -74,7 +73,7 @@ func TestUploadHandlerSendingToExternalStorage(t *testing.T) {
 	storeServerCalled := 0
 	storeServerMux := http.NewServeMux()
 	storeServerMux.HandleFunc("/url/put", func(w http.ResponseWriter, r *http.Request) {
-		assert.Equal(t, "PUT", r.Method)
+		require.Equal(t, "PUT", r.Method)
 
 		receivedData, err := ioutil.ReadAll(r.Body)
 		require.NoError(t, err)
@@ -90,8 +89,8 @@ func TestUploadHandlerSendingToExternalStorage(t *testing.T) {
 
 	responseProcessorCalled := 0
 	responseProcessor := func(w http.ResponseWriter, r *http.Request) {
-		assert.Equal(t, "store-id", r.FormValue("file.remote_id"))
-		assert.NotEmpty(t, r.FormValue("file.remote_url"))
+		require.Equal(t, "store-id", r.FormValue("file.remote_id"))
+		require.NotEmpty(t, r.FormValue("file.remote_url"))
 		w.WriteHeader(200)
 		responseProcessorCalled++
 	}
@@ -99,6 +98,8 @@ func TestUploadHandlerSendingToExternalStorage(t *testing.T) {
 	storeServer := httptest.NewServer(storeServerMux)
 	defer storeServer.Close()
 
+	qs := fmt.Sprintf("?%s=%s", ArtifactFormatKey, ArtifactFormatZip)
+
 	tests := []struct {
 		name    string
 		preauth api.Response
@@ -107,18 +108,7 @@ func TestUploadHandlerSendingToExternalStorage(t *testing.T) {
 			name: "ObjectStore Upload",
 			preauth: api.Response{
 				RemoteObject: api.RemoteObject{
-					StoreURL: storeServer.URL + "/url/put",
-					ID:       "store-id",
-					GetURL:   storeServer.URL + "/store-id",
-				},
-			},
-		},
-		{
-			name: "ObjectStore and FileStore Upload",
-			preauth: api.Response{
-				TempPath: tempPath,
-				RemoteObject: api.RemoteObject{
-					StoreURL: storeServer.URL + "/url/put",
+					StoreURL: storeServer.URL + "/url/put" + qs,
 					ID:       "store-id",
 					GetURL:   storeServer.URL + "/store-id",
 				},
@@ -135,11 +125,11 @@ func TestUploadHandlerSendingToExternalStorage(t *testing.T) {
 			defer ts.Close()
 
 			contentBuffer, contentType := createTestMultipartForm(t, archiveData)
-			response := testUploadArtifacts(t, contentType, ts.URL+Path, &contentBuffer)
-			testhelper.AssertResponseCode(t, response, http.StatusOK)
-			testhelper.AssertResponseHeader(t, response, MetadataHeaderKey, MetadataHeaderPresent)
-			assert.Equal(t, 1, storeServerCalled, "store should be called only once")
-			assert.Equal(t, 1, responseProcessorCalled, "response processor should be called only once")
+			response := testUploadArtifacts(t, contentType, ts.URL+Path+qs, &contentBuffer)
+			require.Equal(t, http.StatusOK, response.Code)
+			testhelper.RequireResponseHeader(t, response, MetadataHeaderKey, MetadataHeaderPresent)
+			require.Equal(t, 1, storeServerCalled, "store should be called only once")
+			require.Equal(t, 1, responseProcessorCalled, "response processor should be called only once")
 		})
 	}
 }
@@ -167,7 +157,7 @@ func TestUploadHandlerSendingToExternalStorageAndStorageServerUnreachable(t *tes
 	defer ts.Close()
 
 	response := testUploadArtifactsFromTestZip(t, ts)
-	testhelper.AssertResponseCode(t, response, http.StatusInternalServerError)
+	require.Equal(t, http.StatusInternalServerError, response.Code)
 }
 
 func TestUploadHandlerSendingToExternalStorageAndInvalidURLIsUsed(t *testing.T) {
@@ -193,22 +183,16 @@ func TestUploadHandlerSendingToExternalStorageAndInvalidURLIsUsed(t *testing.T)
 	defer ts.Close()
 
 	response := testUploadArtifactsFromTestZip(t, ts)
-	testhelper.AssertResponseCode(t, response, http.StatusInternalServerError)
+	require.Equal(t, http.StatusInternalServerError, response.Code)
 }
 
 func TestUploadHandlerSendingToExternalStorageAndItReturnsAnError(t *testing.T) {
-	tempPath, err := ioutil.TempDir("", "uploads")
-	if err != nil {
-		t.Fatal(err)
-	}
-	defer os.RemoveAll(tempPath)
-
 	putCalledTimes := 0
 
 	storeServerMux := http.NewServeMux()
 	storeServerMux.HandleFunc("/url/put", func(w http.ResponseWriter, r *http.Request) {
 		putCalledTimes++
-		assert.Equal(t, "PUT", r.Method)
+		require.Equal(t, "PUT", r.Method)
 		w.WriteHeader(510)
 	})
 
@@ -220,7 +204,6 @@ func TestUploadHandlerSendingToExternalStorageAndItReturnsAnError(t *testing.T)
 	defer storeServer.Close()
 
 	authResponse := api.Response{
-		TempPath: tempPath,
 		RemoteObject: api.RemoteObject{
 			StoreURL: storeServer.URL + "/url/put",
 			ID:       "store-id",
@@ -231,23 +214,17 @@ func TestUploadHandlerSendingToExternalStorageAndItReturnsAnError(t *testing.T)
 	defer ts.Close()
 
 	response := testUploadArtifactsFromTestZip(t, ts)
-	testhelper.AssertResponseCode(t, response, http.StatusInternalServerError)
-	assert.Equal(t, 1, putCalledTimes, "upload should be called only once")
+	require.Equal(t, http.StatusInternalServerError, response.Code)
+	require.Equal(t, 1, putCalledTimes, "upload should be called only once")
 }
 
 func TestUploadHandlerSendingToExternalStorageAndSupportRequestTimeout(t *testing.T) {
-	tempPath, err := ioutil.TempDir("", "uploads")
-	if err != nil {
-		t.Fatal(err)
-	}
-	defer os.RemoveAll(tempPath)
-
 	putCalledTimes := 0
 
 	storeServerMux := http.NewServeMux()
 	storeServerMux.HandleFunc("/url/put", func(w http.ResponseWriter, r *http.Request) {
 		putCalledTimes++
-		assert.Equal(t, "PUT", r.Method)
+		require.Equal(t, "PUT", r.Method)
 		time.Sleep(10 * time.Second)
 		w.WriteHeader(510)
 	})
@@ -260,7 +237,6 @@ func TestUploadHandlerSendingToExternalStorageAndSupportRequestTimeout(t *testin
 	defer storeServer.Close()
 
 	authResponse := api.Response{
-		TempPath: tempPath,
 		RemoteObject: api.RemoteObject{
 			StoreURL: storeServer.URL + "/url/put",
 			ID:       "store-id",
@@ -272,8 +248,8 @@ func TestUploadHandlerSendingToExternalStorageAndSupportRequestTimeout(t *testin
 	defer ts.Close()
 
 	response := testUploadArtifactsFromTestZip(t, ts)
-	testhelper.AssertResponseCode(t, response, http.StatusInternalServerError)
-	assert.Equal(t, 1, putCalledTimes, "upload should be called only once")
+	require.Equal(t, http.StatusInternalServerError, response.Code)
+	require.Equal(t, 1, putCalledTimes, "upload should be called only once")
 }
 
 func TestUploadHandlerMultipartUploadSizeLimit(t *testing.T) {
@@ -285,13 +261,12 @@ func TestUploadHandlerMultipartUploadSizeLimit(t *testing.T) {
 
 	objectURL := server.URL + test.ObjectPath
 
-	partSize := int64(1)
 	uploadSize := 10
 	preauth := api.Response{
 		RemoteObject: api.RemoteObject{
 			ID: "store-id",
 			MultipartUpload: &api.MultipartUploadParams{
-				PartSize:    partSize,
+				PartSize:    1,
 				PartURLs:    []string{objectURL + "?partNumber=1"},
 				AbortURL:    objectURL, // DELETE
 				CompleteURL: objectURL, // POST
@@ -308,12 +283,56 @@ func TestUploadHandlerMultipartUploadSizeLimit(t *testing.T) {
 
 	contentBuffer, contentType := createTestMultipartForm(t, make([]byte, uploadSize))
 	response := testUploadArtifacts(t, contentType, ts.URL+Path, &contentBuffer)
-	testhelper.AssertResponseCode(t, response, http.StatusRequestEntityTooLarge)
+	require.Equal(t, http.StatusRequestEntityTooLarge, response.Code)
 
 	// Poll because AbortMultipartUpload is async
 	for i := 0; os.IsMultipartUpload(test.ObjectPath) && i < 100; i++ {
 		time.Sleep(10 * time.Millisecond)
 	}
-	assert.False(t, os.IsMultipartUpload(test.ObjectPath), "MultipartUpload should not be in progress anymore")
-	assert.Empty(t, os.GetObjectMD5(test.ObjectPath), "upload should have failed, so the object should not exists")
+	require.False(t, os.IsMultipartUpload(test.ObjectPath), "MultipartUpload should not be in progress anymore")
+	require.Empty(t, os.GetObjectMD5(test.ObjectPath), "upload should have failed, so the object should not exists")
+}
+
+func TestUploadHandlerMultipartUploadMaximumSizeFromApi(t *testing.T) {
+	os, server := test.StartObjectStore()
+	defer server.Close()
+
+	err := os.InitiateMultipartUpload(test.ObjectPath)
+	require.NoError(t, err)
+
+	objectURL := server.URL + test.ObjectPath
+
+	uploadSize := int64(10)
+	maxSize := uploadSize - 1
+	preauth := api.Response{
+		MaximumSize: maxSize,
+		RemoteObject: api.RemoteObject{
+			ID: "store-id",
+			MultipartUpload: &api.MultipartUploadParams{
+				PartSize:    uploadSize,
+				PartURLs:    []string{objectURL + "?partNumber=1"},
+				AbortURL:    objectURL, // DELETE
+				CompleteURL: objectURL, // POST
+			},
+		},
+	}
+
+	responseProcessor := func(w http.ResponseWriter, r *http.Request) {
+		t.Fatal("it should not be called")
+	}
+
+	ts := testArtifactsUploadServer(t, preauth, responseProcessor)
+	defer ts.Close()
+
+	contentBuffer, contentType := createTestMultipartForm(t, make([]byte, uploadSize))
+	response := testUploadArtifacts(t, contentType, ts.URL+Path, &contentBuffer)
+	require.Equal(t, http.StatusRequestEntityTooLarge, response.Code)
+
+	testhelper.Retry(t, 5*time.Second, func() error {
+		if os.GetObjectMD5(test.ObjectPath) == "" {
+			return nil
+		}
+
+		return fmt.Errorf("file is still present")
+	})
 }
