@@ -15,7 +15,7 @@ import (
 	"regexp"
 	"time"
 
-	"github.com/golang/protobuf/proto"
+	"github.com/golang/protobuf/proto" //lint:ignore SA1019 https://gitlab.com/gitlab-org/gitlab-workhorse/-/issues/274
 
 	"github.com/prometheus/client_golang/prometheus"
 
