@@ -1,6 +1,9 @@
 package parser
 
 import (
+	"context"
+	"io"
+	"io/ioutil"
 	"os"
 	"runtime"
 	"testing"
@@ -19,12 +22,12 @@ func BenchmarkGenerate(b *testing.B) {
 			file, err := os.Open(filePath)
 			require.NoError(b, err)
 
-			p, err := NewParser(file, Config{ProcessReferences: true})
+			parser, err := NewParser(context.Background(), file, Config{})
 			require.NoError(b, err)
 
-			_, err = p.ZipReader()
+			_, err = io.Copy(ioutil.Discard, parser)
 			require.NoError(b, err)
-			require.NoError(b, p.Close())
+			require.NoError(b, parser.Close())
 		})
 	}
 
