@@ -9,7 +9,6 @@ import (
 	"testing"
 	"time"
 
-	"github.com/stretchr/testify/assert"
 	"github.com/stretchr/testify/require"
 
 	"gitlab.com/gitlab-org/gitlab-workhorse/internal/objectstore"
@@ -21,8 +20,6 @@ const testTimeout = 10 * time.Second
 type osFactory func() (*test.ObjectstoreStub, *httptest.Server)
 
 func testObjectUploadNoErrors(t *testing.T, startObjectStore osFactory, useDeleteURL bool, contentType string) {
-	assert := assert.New(t)
-
 	osStub, ts := startObjectStore()
 	defer ts.Close()
 
@@ -38,26 +35,22 @@ func testObjectUploadNoErrors(t *testing.T, startObjectStore osFactory, useDelet
 	defer cancel()
 
 	deadline := time.Now().Add(testTimeout)
-	object, err := objectstore.NewObject(ctx, objectURL, deleteURL, putHeaders, deadline, test.ObjectSize)
+	object, err := objectstore.NewObject(objectURL, deleteURL, putHeaders, test.ObjectSize)
 	require.NoError(t, err)
 
 	// copy data
-	n, err := io.Copy(object, strings.NewReader(test.ObjectContent))
-	assert.NoError(err)
-	assert.Equal(test.ObjectSize, n, "Uploaded file mismatch")
+	n, err := object.Consume(ctx, strings.NewReader(test.ObjectContent), deadline)
+	require.NoError(t, err)
+	require.Equal(t, test.ObjectSize, n, "Uploaded file mismatch")
 
-	// close HTTP stream
-	err = object.Close()
-	assert.NoError(err)
-
-	assert.Equal(contentType, osStub.GetHeader(test.ObjectPath, "Content-Type"))
+	require.Equal(t, contentType, osStub.GetHeader(test.ObjectPath, "Content-Type"))
 
 	// Checking MD5 extraction
-	assert.Equal(osStub.GetObjectMD5(test.ObjectPath), object.ETag())
+	require.Equal(t, osStub.GetObjectMD5(test.ObjectPath), object.ETag())
 
 	// Checking cleanup
 	cancel()
-	assert.Equal(1, osStub.PutsCnt(), "Object hasn't been uploaded")
+	require.Equal(t, 1, osStub.PutsCnt(), "Object hasn't been uploaded")
 
 	var expectedDeleteCnt int
 	if useDeleteURL {
@@ -72,9 +65,9 @@ func testObjectUploadNoErrors(t *testing.T, startObjectStore osFactory, useDelet
 	}
 
 	if useDeleteURL {
-		assert.Equal(1, osStub.DeletesCnt(), "Object hasn't been deleted")
+		require.Equal(t, 1, osStub.DeletesCnt(), "Object hasn't been deleted")
 	} else {
-		assert.Equal(0, osStub.DeletesCnt(), "Object has been deleted")
+		require.Equal(t, 0, osStub.DeletesCnt(), "Object has been deleted")
 	}
 }
 
@@ -102,9 +95,6 @@ func TestObjectUpload(t *testing.T) {
 }
 
 func TestObjectUpload404(t *testing.T) {
-	assert := assert.New(t)
-	require := require.New(t)
-
 	ts := httptest.NewServer(http.NotFoundHandler())
 	defer ts.Close()
 
@@ -113,16 +103,14 @@ func TestObjectUpload404(t *testing.T) {
 
 	deadline := time.Now().Add(testTimeout)
 	objectURL := ts.URL + test.ObjectPath
-	object, err := objectstore.NewObject(ctx, objectURL, "", map[string]string{}, deadline, test.ObjectSize)
-	require.NoError(err)
-	_, err = io.Copy(object, strings.NewReader(test.ObjectContent))
+	object, err := objectstore.NewObject(objectURL, "", map[string]string{}, test.ObjectSize)
+	require.NoError(t, err)
+	_, err = object.Consume(ctx, strings.NewReader(test.ObjectContent), deadline)
 
-	assert.NoError(err)
-	err = object.Close()
-	assert.Error(err)
+	require.Error(t, err)
 	_, isStatusCodeError := err.(objectstore.StatusCodeError)
-	require.True(isStatusCodeError, "Should fail with StatusCodeError")
-	require.Contains(err.Error(), "404")
+	require.True(t, isStatusCodeError, "Should fail with StatusCodeError")
+	require.Contains(t, err.Error(), "404")
 }
 
 type endlessReader struct{}
@@ -158,13 +146,10 @@ func TestObjectUploadBrokenConnection(t *testing.T) {
 
 	deadline := time.Now().Add(testTimeout)
 	objectURL := ts.URL + test.ObjectPath
-	object, err := objectstore.NewObject(ctx, objectURL, "", map[string]string{}, deadline, -1)
+	object, err := objectstore.NewObject(objectURL, "", map[string]string{}, -1)
 	require.NoError(t, err)
 
-	_, copyErr := io.Copy(object, &endlessReader{})
+	_, copyErr := object.Consume(ctx, &endlessReader{}, deadline)
 	require.Error(t, copyErr)
 	require.NotEqual(t, io.ErrClosedPipe, copyErr, "We are shadowing the real error")
-
-	closeErr := object.Close()
-	require.Equal(t, copyErr, closeErr)
 }
