@@ -3,7 +3,6 @@ package objectstore_test
 import (
 	"context"
 	"fmt"
-	"io"
 	"io/ioutil"
 	"os"
 	"path/filepath"
@@ -19,6 +18,7 @@ import (
 	"gitlab.com/gitlab-org/gitlab-workhorse/internal/config"
 	"gitlab.com/gitlab-org/gitlab-workhorse/internal/objectstore"
 	"gitlab.com/gitlab-org/gitlab-workhorse/internal/objectstore/test"
+	"gitlab.com/gitlab-org/gitlab-workhorse/internal/testhelper"
 )
 
 func TestS3ObjectUpload(t *testing.T) {
@@ -43,34 +43,26 @@ func TestS3ObjectUpload(t *testing.T) {
 			objectName := filepath.Join(tmpDir, "s3-test-data")
 			ctx, cancel := context.WithCancel(context.Background())
 
-			object, err := objectstore.NewS3Object(ctx, objectName, creds, config, deadline)
+			object, err := objectstore.NewS3Object(objectName, creds, config)
 			require.NoError(t, err)
 
 			// copy data
-			n, err := io.Copy(object, strings.NewReader(test.ObjectContent))
+			n, err := object.Consume(ctx, strings.NewReader(test.ObjectContent), deadline)
 			require.NoError(t, err)
 			require.Equal(t, test.ObjectSize, n, "Uploaded file mismatch")
 
-			// close HTTP stream
-			err = object.Close()
-			require.NoError(t, err)
-
 			test.S3ObjectExists(t, sess, config, objectName, test.ObjectContent)
 			test.CheckS3Metadata(t, sess, config, objectName)
 
 			cancel()
-			deleted := false
 
-			retry(3, time.Second, func() error {
+			testhelper.Retry(t, 5*time.Second, func() error {
 				if test.S3ObjectDoesNotExist(t, sess, config, objectName) {
-					deleted = true
 					return nil
-				} else {
-					return fmt.Errorf("file is still present, retrying")
 				}
-			})
 
-			require.True(t, deleted)
+				return fmt.Errorf("file is still present")
+			})
 		})
 	}
 }
@@ -110,17 +102,14 @@ func TestConcurrentS3ObjectUpload(t *testing.T) {
 			ctx, cancel := context.WithCancel(context.Background())
 			defer cancel()
 
-			object, err := objectstore.NewS3Object(ctx, objectName, creds, config, deadline)
+			object, err := objectstore.NewS3Object(objectName, creds, config)
 			require.NoError(t, err)
 
 			// copy data
-			n, err := io.Copy(object, strings.NewReader(test.ObjectContent))
+			n, err := object.Consume(ctx, strings.NewReader(test.ObjectContent), deadline)
 			require.NoError(t, err)
 			require.Equal(t, test.ObjectSize, n, "Uploaded file mismatch")
 
-			// close HTTP stream
-			require.NoError(t, object.Close())
-
 			test.S3ObjectExists(t, sess, config, objectName, test.ObjectContent)
 			wg.Done()
 		}(i)
@@ -142,7 +131,7 @@ func TestS3ObjectUploadCancel(t *testing.T) {
 
 	objectName := filepath.Join(tmpDir, "s3-test-data")
 
-	object, err := objectstore.NewS3Object(ctx, objectName, creds, config, deadline)
+	object, err := objectstore.NewS3Object(objectName, creds, config)
 
 	require.NoError(t, err)
 
@@ -150,26 +139,6 @@ func TestS3ObjectUploadCancel(t *testing.T) {
 	// we handle this gracefully.
 	cancel()
 
-	_, err = io.Copy(object, strings.NewReader(test.ObjectContent))
+	_, err = object.Consume(ctx, strings.NewReader(test.ObjectContent), deadline)
 	require.Error(t, err)
 }
-
-func retry(attempts int, sleep time.Duration, fn func() error) error {
-	if err := fn(); err != nil {
-		if s, ok := err.(stop); ok {
-			// Return the original error for later checking
-			return s.error
-		}
-
-		if attempts--; attempts > 0 {
-			time.Sleep(sleep)
-			return retry(attempts, 2*sleep, fn)
-		}
-		return err
-	}
-	return nil
-}
-
-type stop struct {
-	error
-}
