@@ -7,21 +7,21 @@ import (
 )
 
 type ObjectStoragePreparer struct {
+	config      config.ObjectStorageConfig
 	credentials config.ObjectStorageCredentials
 }
 
 func NewObjectStoragePreparer(c config.Config) Preparer {
-	creds := c.ObjectStorageCredentials
-
-	if creds == nil {
-		creds = &config.ObjectStorageCredentials{}
-	}
-
-	return &ObjectStoragePreparer{credentials: *creds}
+	return &ObjectStoragePreparer{credentials: c.ObjectStorageCredentials, config: c.ObjectStorageConfig}
 }
 
 func (p *ObjectStoragePreparer) Prepare(a *api.Response) (*filestore.SaveFileOpts, Verifier, error) {
-	opts := filestore.GetOpts(a)
+	opts, err := filestore.GetOpts(a)
+	if err != nil {
+		return nil, nil, err
+	}
+
+	opts.ObjectStorageConfig.URLMux = p.config.URLMux
 	opts.ObjectStorageConfig.S3Credentials = p.credentials.S3Credentials
 
 	return opts, nil, nil
