@@ -6,6 +6,7 @@ import (
 	"encoding/base64"
 	"encoding/json"
 	"fmt"
+	"image/png"
 	"io"
 	"io/ioutil"
 	"net/http"
@@ -21,7 +22,6 @@ import (
 	"time"
 
 	"github.com/sirupsen/logrus"
-	"github.com/stretchr/testify/assert"
 	"github.com/stretchr/testify/require"
 	"gitlab.com/gitlab-org/gitaly/proto/go/gitalypb"
 	"gitlab.com/gitlab-org/labkit/log"
@@ -38,6 +38,9 @@ import (
 const scratchDir = "testdata/scratch"
 const testRepoRoot = "testdata/data"
 const testDocumentRoot = "testdata/public"
+
+var absDocumentRoot string
+
 const testRepo = "group/test.git"
 const testProject = "group/test"
 
@@ -63,7 +66,7 @@ func TestDeniedClone(t *testing.T) {
 	require.NoError(t, os.RemoveAll(scratchDir))
 
 	// Prepare test server and backend
-	ts := testAuthServer(nil, nil, 403, "Access denied")
+	ts := testAuthServer(t, nil, nil, 403, "Access denied")
 	defer ts.Close()
 	ws := startWorkhorseServer(ts.URL)
 	defer ws.Close()
@@ -72,12 +75,12 @@ func TestDeniedClone(t *testing.T) {
 	cloneCmd := exec.Command("git", "clone", fmt.Sprintf("%s/%s", ws.URL, testRepo), checkoutDir)
 	out, err := cloneCmd.CombinedOutput()
 	t.Log(string(out))
-	assert.Error(t, err, "git clone should have failed")
+	require.Error(t, err, "git clone should have failed")
 }
 
 func TestDeniedPush(t *testing.T) {
 	// Prepare the test server and backend
-	ts := testAuthServer(nil, nil, 403, "Access denied")
+	ts := testAuthServer(t, nil, nil, 403, "Access denied")
 	defer ts.Close()
 	ws := startWorkhorseServer(ts.URL)
 	defer ws.Close()
@@ -87,7 +90,7 @@ func TestDeniedPush(t *testing.T) {
 	pushCmd.Dir = checkoutDir
 	out, err := pushCmd.CombinedOutput()
 	t.Log(string(out))
-	assert.Error(t, err, "git push should have failed")
+	require.Error(t, err, "git push should have failed")
 }
 
 func TestRegularProjectsAPI(t *testing.T) {
@@ -112,9 +115,9 @@ func TestRegularProjectsAPI(t *testing.T) {
 	} {
 		resp, body := httpGet(t, ws.URL+resource, nil)
 
-		assert.Equal(t, 200, resp.StatusCode, "GET %q: status code", resource)
-		assert.Equal(t, apiResponse, body, "GET %q: response body", resource)
-		assertNginxResponseBuffering(t, "", resp, "GET %q: nginx response buffering", resource)
+		require.Equal(t, 200, resp.StatusCode, "GET %q: status code", resource)
+		require.Equal(t, apiResponse, body, "GET %q: response body", resource)
+		requireNginxResponseBuffering(t, "", resp, "GET %q: nginx response buffering", resource)
 	}
 }
 
@@ -151,10 +154,10 @@ func TestAllowedStaticFile(t *testing.T) {
 	} {
 		resp, body := httpGet(t, ws.URL+resource, nil)
 
-		assert.Equal(t, 200, resp.StatusCode, "GET %q: status code", resource)
-		assert.Equal(t, content, body, "GET %q: response body", resource)
-		assertNginxResponseBuffering(t, "no", resp, "GET %q: nginx response buffering", resource)
-		assert.False(t, proxied, "GET %q: should not have made it to backend", resource)
+		require.Equal(t, 200, resp.StatusCode, "GET %q: status code", resource)
+		require.Equal(t, content, body, "GET %q: response body", resource)
+		requireNginxResponseBuffering(t, "no", resp, "GET %q: nginx response buffering", resource)
+		require.False(t, proxied, "GET %q: should not have made it to backend", resource)
 	}
 }
 
@@ -172,8 +175,8 @@ func TestStaticFileRelativeURL(t *testing.T) {
 	resource := "/my-relative-url/static.txt"
 	resp, body := httpGet(t, ws.URL+resource, nil)
 
-	assert.Equal(t, 200, resp.StatusCode, "GET %q: status code", resource)
-	assert.Equal(t, content, body, "GET %q: response body", resource)
+	require.Equal(t, 200, resp.StatusCode, "GET %q: status code", resource)
+	require.Equal(t, content, body, "GET %q: response body", resource)
 }
 
 func TestAllowedPublicUploadsFile(t *testing.T) {
@@ -183,7 +186,7 @@ func TestAllowedPublicUploadsFile(t *testing.T) {
 	proxied := false
 	ts := testhelper.TestServerWithHandler(regexp.MustCompile(`.`), func(w http.ResponseWriter, r *http.Request) {
 		proxied = true
-		w.Header().Add("X-Sendfile", *documentRoot+r.URL.Path)
+		w.Header().Add("X-Sendfile", absDocumentRoot+r.URL.Path)
 		w.WriteHeader(200)
 	})
 	defer ts.Close()
@@ -196,9 +199,9 @@ func TestAllowedPublicUploadsFile(t *testing.T) {
 	} {
 		resp, body := httpGet(t, ws.URL+resource, nil)
 
-		assert.Equal(t, 200, resp.StatusCode, "GET %q: status code", resource)
-		assert.Equal(t, content, body, "GET %q: response body", resource)
-		assert.True(t, proxied, "GET %q: never made it to backend", resource)
+		require.Equal(t, 200, resp.StatusCode, "GET %q: status code", resource)
+		require.Equal(t, content, body, "GET %q: response body", resource)
+		require.True(t, proxied, "GET %q: never made it to backend", resource)
 	}
 }
 
@@ -221,9 +224,9 @@ func TestDeniedPublicUploadsFile(t *testing.T) {
 	} {
 		resp, body := httpGet(t, ws.URL+resource, nil)
 
-		assert.Equal(t, 404, resp.StatusCode, "GET %q: status code", resource)
-		assert.Equal(t, "", body, "GET %q: response body", resource)
-		assert.True(t, proxied, "GET %q: never made it to backend", resource)
+		require.Equal(t, 404, resp.StatusCode, "GET %q: status code", resource)
+		require.Equal(t, "", body, "GET %q: response body", resource)
+		require.True(t, proxied, "GET %q: never made it to backend", resource)
 	}
 }
 
@@ -252,8 +255,8 @@ This is a static error page for code 499
 	resourcePath := "/error-499"
 	resp, body := httpGet(t, ws.URL+resourcePath, nil)
 
-	assert.Equal(t, 499, resp.StatusCode, "GET %q: status code", resourcePath)
-	assert.Equal(t, string(errorPageBody), body, "GET %q: response body", resourcePath)
+	require.Equal(t, 499, resp.StatusCode, "GET %q: status code", resourcePath)
+	require.Equal(t, string(errorPageBody), body, "GET %q: response body", resourcePath)
 }
 
 func TestGzipAssets(t *testing.T) {
@@ -302,10 +305,10 @@ func TestGzipAssets(t *testing.T) {
 		b, err := ioutil.ReadAll(resp.Body)
 		require.NoError(t, err, desc)
 
-		assert.Equal(t, 200, resp.StatusCode, "%s: status code", desc)
-		assert.Equal(t, tc.content, string(b), "%s: response body", desc)
-		assert.Equal(t, tc.contentEncoding, resp.Header.Get("Content-Encoding"), "%s: response body", desc)
-		assert.False(t, proxied, "%s: should not have made it to backend", desc)
+		require.Equal(t, 200, resp.StatusCode, "%s: status code", desc)
+		require.Equal(t, tc.content, string(b), "%s: response body", desc)
+		require.Equal(t, tc.contentEncoding, resp.Header.Get("Content-Encoding"), "%s: response body", desc)
+		require.False(t, proxied, "%s: should not have made it to backend", desc)
 	}
 }
 
@@ -363,9 +366,27 @@ func TestArtifactsGetSingleFile(t *testing.T) {
 	resp, body, err := doSendDataRequest(resourcePath, "artifacts-entry", jsonParams)
 	require.NoError(t, err)
 
-	assert.Equal(t, 200, resp.StatusCode, "GET %q: status code", resourcePath)
-	assert.Equal(t, fileContents, string(body), "GET %q: response body", resourcePath)
-	assertNginxResponseBuffering(t, "no", resp, "GET %q: nginx response buffering", resourcePath)
+	require.Equal(t, 200, resp.StatusCode, "GET %q: status code", resourcePath)
+	require.Equal(t, fileContents, string(body), "GET %q: response body", resourcePath)
+	requireNginxResponseBuffering(t, "no", resp, "GET %q: nginx response buffering", resourcePath)
+}
+
+func TestImageResizing(t *testing.T) {
+	imageLocation := `testdata/image.png`
+	requestedWidth := 40
+	imageFormat := "image/png"
+	jsonParams := fmt.Sprintf(`{"Location":"%s","Width":%d, "ContentType":"%s"}`, imageLocation, requestedWidth, imageFormat)
+	resourcePath := "/uploads/-/system/user/avatar/123/avatar.png?width=40"
+
+	resp, body, err := doSendDataRequest(resourcePath, "send-scaled-img", jsonParams)
+	require.NoError(t, err, "send resize request")
+	require.Equal(t, 200, resp.StatusCode, "GET %q: body: %s", resourcePath, body)
+
+	img, err := png.Decode(bytes.NewReader(body))
+	require.NoError(t, err, "decode resized image")
+
+	bounds := img.Bounds()
+	require.Equal(t, requestedWidth, bounds.Size().X, "wrong width after resizing")
 }
 
 func TestSendURLForArtifacts(t *testing.T) {
@@ -418,7 +439,7 @@ func TestSendURLForArtifacts(t *testing.T) {
 			require.Equal(t, int64(tc.contentLength), resp.ContentLength, "GET %q: Content-Length", resourcePath)
 			require.Equal(t, tc.transferEncoding, resp.TransferEncoding, "GET %q: Transfer-Encoding", resourcePath)
 			require.Equal(t, expectedBody, string(body), "GET %q: response body", resourcePath)
-			assertNginxResponseBuffering(t, "no", resp, "GET %q: nginx response buffering", resourcePath)
+			requireNginxResponseBuffering(t, "no", resp, "GET %q: nginx response buffering", resourcePath)
 		})
 	}
 }
@@ -438,8 +459,8 @@ func TestApiContentTypeBlock(t *testing.T) {
 	resourcePath := "/something"
 	resp, body := httpGet(t, ws.URL+resourcePath, nil)
 
-	assert.Equal(t, 500, resp.StatusCode, "GET %q: status code", resourcePath)
-	assert.NotContains(t, wrongResponse, body, "GET %q: response body", resourcePath)
+	require.Equal(t, 500, resp.StatusCode, "GET %q: status code", resourcePath)
+	require.NotContains(t, wrongResponse, body, "GET %q: response body", resourcePath)
 }
 
 func TestAPIFalsePositivesAreProxied(t *testing.T) {
@@ -471,22 +492,20 @@ func TestAPIFalsePositivesAreProxied(t *testing.T) {
 		{"PUT", "/nested/group/project/blob/master/foo.git/gitlab-lfs/objects/0000000000000000000000000000000000000000000000000000000000000000/0"},
 		{"GET", "/nested/group/project/blob/master/environments/1/terminal.ws"},
 	} {
-		req, err := http.NewRequest(tc.method, ws.URL+tc.path, nil)
-		if !assert.NoError(t, err, "Constructing %s %q", tc.method, tc.path) {
-			continue
-		}
-		resp, err := http.DefaultClient.Do(req)
-		if !assert.NoError(t, err, "%s %q", tc.method, tc.path) {
-			continue
-		}
-		defer resp.Body.Close()
+		t.Run(tc.method+"_"+tc.path, func(t *testing.T) {
+			req, err := http.NewRequest(tc.method, ws.URL+tc.path, nil)
+			require.NoError(t, err, "Constructing %s %q", tc.method, tc.path)
+			resp, err := http.DefaultClient.Do(req)
+			require.NoError(t, err, "%s %q", tc.method, tc.path)
+			defer resp.Body.Close()
 
-		respBody, err := ioutil.ReadAll(resp.Body)
-		assert.NoError(t, err, "%s %q: reading body", tc.method, tc.path)
+			respBody, err := ioutil.ReadAll(resp.Body)
+			require.NoError(t, err, "%s %q: reading body", tc.method, tc.path)
 
-		assert.Equal(t, 200, resp.StatusCode, "%s %q: status code", tc.method, tc.path)
-		testhelper.AssertResponseHeader(t, resp, "Content-Type", "text/html")
-		assert.Equal(t, string(goodResponse), string(respBody), "%s %q: response body", tc.method, tc.path)
+			require.Equal(t, 200, resp.StatusCode, "%s %q: status code", tc.method, tc.path)
+			testhelper.RequireResponseHeader(t, resp, "Content-Type", "text/html")
+			require.Equal(t, string(goodResponse), string(respBody), "%s %q: response body", tc.method, tc.path)
+		})
 	}
 }
 
@@ -504,9 +523,9 @@ func TestCorrelationIdHeader(t *testing.T) {
 	} {
 		resp, _ := httpGet(t, ws.URL+resource, nil)
 
-		assert.Equal(t, 200, resp.StatusCode, "GET %q: status code", resource)
+		require.Equal(t, 200, resp.StatusCode, "GET %q: status code", resource)
 		requestIds := resp.Header["X-Request-Id"]
-		assert.Equal(t, 1, len(requestIds), "GET %q: One X-Request-Id present", resource)
+		require.Equal(t, 1, len(requestIds), "GET %q: One X-Request-Id present", resource)
 	}
 }
 
@@ -544,28 +563,46 @@ func TestPropagateCorrelationIdHeader(t *testing.T) {
 			resp, _ := httpGet(t, ws.URL+resource, map[string]string{"X-Request-Id": propagatedRequestId})
 			requestIds := resp.Header["X-Request-Id"]
 
-			assert.Equal(t, 200, resp.StatusCode, "GET %q: status code", resource)
-			assert.Equal(t, 1, len(requestIds), "GET %q: One X-Request-Id present", resource)
+			require.Equal(t, 200, resp.StatusCode, "GET %q: status code", resource)
+			require.Equal(t, 1, len(requestIds), "GET %q: One X-Request-Id present", resource)
 
 			if tc.propagateCorrelationID {
-				assert.Contains(t, requestIds, propagatedRequestId, "GET %q: Has X-Request-Id %s present", resource, propagatedRequestId)
+				require.Contains(t, requestIds, propagatedRequestId, "GET %q: Has X-Request-Id %s present", resource, propagatedRequestId)
 			} else {
-				assert.NotContains(t, requestIds, propagatedRequestId, "GET %q: X-Request-Id not propagated")
+				require.NotContains(t, requestIds, propagatedRequestId, "GET %q: X-Request-Id not propagated")
 			}
 		})
 	}
 }
 
+func TestRejectUnknownMethod(t *testing.T) {
+	ts := testhelper.TestServerWithHandler(regexp.MustCompile(`.`), func(w http.ResponseWriter, r *http.Request) {
+		w.WriteHeader(200)
+	})
+	defer ts.Close()
+	ws := startWorkhorseServer(ts.URL)
+	defer ws.Close()
+
+	req, err := http.NewRequest("UNKNOWN", ws.URL+"/api/v3/projects/123/repository/not/special", nil)
+	require.NoError(t, err)
+
+	resp, err := http.DefaultClient.Do(req)
+	require.NoError(t, err)
+	defer resp.Body.Close()
+
+	require.Equal(t, http.StatusMethodNotAllowed, resp.StatusCode)
+}
+
 func setupStaticFile(fpath, content string) error {
 	cwd, err := os.Getwd()
 	if err != nil {
 		return err
 	}
-	*documentRoot = path.Join(cwd, testDocumentRoot)
-	if err := os.MkdirAll(path.Join(*documentRoot, path.Dir(fpath)), 0755); err != nil {
+	absDocumentRoot = path.Join(cwd, testDocumentRoot)
+	if err := os.MkdirAll(path.Join(absDocumentRoot, path.Dir(fpath)), 0755); err != nil {
 		return err
 	}
-	staticFile := path.Join(*documentRoot, fpath)
+	staticFile := path.Join(absDocumentRoot, fpath)
 	return ioutil.WriteFile(staticFile, []byte(content), 0666)
 }
 
@@ -578,8 +615,10 @@ func newBranch() string {
 	return fmt.Sprintf("branch-%d", time.Now().UnixNano())
 }
 
-func testAuthServer(url *regexp.Regexp, params url.Values, code int, body interface{}) *httptest.Server {
+func testAuthServer(t *testing.T, url *regexp.Regexp, params url.Values, code int, body interface{}) *httptest.Server {
 	return testhelper.TestServerWithHandler(url, func(w http.ResponseWriter, r *http.Request) {
+		require.NotEmpty(t, r.Header.Get("X-Request-Id"))
+
 		w.Header().Set("Content-Type", api.ResponseContentType)
 
 		logEntry := log.WithFields(log.Fields{
@@ -627,9 +666,10 @@ func testAuthServer(url *regexp.Regexp, params url.Values, code int, body interf
 
 func newUpstreamConfig(authBackend string) *config.Config {
 	return &config.Config{
-		Version:      "123",
-		DocumentRoot: testDocumentRoot,
-		Backend:      helper.URLMustParse(authBackend),
+		Version:            "123",
+		DocumentRoot:       testDocumentRoot,
+		Backend:            helper.URLMustParse(authBackend),
+		ImageResizerConfig: config.DefaultImageResizerConfig,
 	}
 }
 
@@ -693,9 +733,9 @@ func httpPost(t *testing.T, url string, headers map[string]string, reqBody io.Re
 	return resp
 }
 
-func assertNginxResponseBuffering(t *testing.T, expected string, resp *http.Response, msgAndArgs ...interface{}) {
+func requireNginxResponseBuffering(t *testing.T, expected string, resp *http.Response, msgAndArgs ...interface{}) {
 	actual := resp.Header.Get(helper.NginxResponseBufferHeader)
-	assert.Equal(t, expected, actual, msgAndArgs...)
+	require.Equal(t, expected, actual, msgAndArgs...)
 }
 
 // TestHealthChecksNoStaticHTML verifies that health endpoints pass errors through and don't return the static html error pages
@@ -728,9 +768,9 @@ This is a static error page for code 503
 		t.Run(resource, func(t *testing.T) {
 			resp, body := httpGet(t, ws.URL+resource, nil)
 
-			assert.Equal(t, 503, resp.StatusCode, "status code")
-			assert.Equal(t, apiResponse, body, "response body")
-			assertNginxResponseBuffering(t, "", resp, "nginx response buffering")
+			require.Equal(t, 503, resp.StatusCode, "status code")
+			require.Equal(t, apiResponse, body, "response body")
+			requireNginxResponseBuffering(t, "", resp, "nginx response buffering")
 		})
 	}
 }
@@ -754,10 +794,10 @@ func TestHealthChecksUnreachable(t *testing.T) {
 		t.Run(tc.path, func(t *testing.T) {
 			resp, body := httpGet(t, ws.URL+tc.path, nil)
 
-			assert.Equal(t, 502, resp.StatusCode, "status code")
-			assert.Equal(t, tc.responseType, resp.Header.Get("Content-Type"), "content-type")
-			assert.Equal(t, tc.content, body, "response body")
-			assertNginxResponseBuffering(t, "", resp, "nginx response buffering")
+			require.Equal(t, 502, resp.StatusCode, "status code")
+			require.Equal(t, tc.responseType, resp.Header.Get("Content-Type"), "content-type")
+			require.Equal(t, tc.content, body, "response body")
+			requireNginxResponseBuffering(t, "", resp, "nginx response buffering")
 		})
 	}
 }
